@@ -167,7 +167,7 @@ class CoolAutomationClient(Singleton):
     """
 
     UNAUTHORIZES_ERROR_CODE = 401
-    SOCKET_URI = "wss://api.coolremote.net/api/v1/"
+    SOCKET_URI = "wss://api.coolremote.net:443/ws/v1"
 
     @classmethod
     async def create(cls, token, logger=None):
