@@ -1,6 +1,5 @@
-from asyncore import loop
 import unittest
-
+from time import sleep
 import asyncio
 from cool_open_client.cool_automation_client import CoolAutomationClient
 
@@ -13,10 +12,9 @@ class TestWebSocket(unittest.TestCase):
 
     def test_websocket(self):
         client = self.loop.run_until_complete(CoolAutomationClient.create(self.token))
-        task = self.loop.create_task(client.open_socket())
-        # while not task.done:
-        #     asyncio.slee(10)
-        self.loop.run_until_complete(task)
+        client.open_socket()
+        # sleep(60)
+        # self.loop.run_until_complete(task)
 
 
 if __name__ == "__main__":
